==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/bma/v20210624/models/DescribeBPFakeURLsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.bma.v20210624.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeBPFakeURLsResponse extends AbstractModel {

    /**
    * 仿冒网址列表
    */
    @SerializedName("FakeURLInfos")
    @Expose
    private FakeURLInfo [] FakeURLInfos;

    /**
    * 总量
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 导出量
    */
    @SerializedName("ExportURL")
    @Expose
    private String ExportURL;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 仿冒网址列表 
     * @return FakeURLInfos 仿冒网址列表
     */
    public FakeURLInfo [] getFakeURLInfos() {
        return this.FakeURLInfos;
    }

    /**
     * Set 仿冒网址列表
     * @param FakeURLInfos 仿冒网址列表
     */
    public void setFakeURLInfos(FakeURLInfo [] FakeURLInfos) {
        this.FakeURLInfos = FakeURLInfos;
    }

    /**
     * Get 总量 
     * @return TotalCount 总量
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 总量
     * @param TotalCount 总量
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 导出量 
     * @return ExportURL 导出量
     */
    public String getExportURL() {
        return this.ExportURL;
    }

    /**
     * Set 导出量
     * @param ExportURL 导出量
     */
    public void setExportURL(String ExportURL) {
        this.ExportURL = ExportURL;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeBPFakeURLsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeBPFakeURLsResponse(DescribeBPFakeURLsResponse source) {
        if (source.FakeURLInfos != null) {
            this.FakeURLInfos = new FakeURLInfo[source.FakeURLInfos.length];
            for (int i = 0; i < source.FakeURLInfos.length; i++) {
                this.FakeURLInfos[i] = new FakeURLInfo(source.FakeURLInfos[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.ExportURL != null) {
            this.ExportURL = new String(source.ExportURL);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "FakeURLInfos.", this.FakeURLInfos);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "ExportURL", this.ExportURL);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1157-sources.jar: com/tencentcloudapi/bma/v20210624/models/DescribeBPFakeURLsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.bma.v20210624.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeBPFakeURLsResponse extends AbstractModel {

    /**
    * 仿冒网址列表
    */
    @SerializedName("FakeURLInfos")
    @Expose
    private FakeURLInfo [] FakeURLInfos;

    /**
    * 总量
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 导出量
    */
    @SerializedName("ExportURL")
    @Expose
    private String ExportURL;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 仿冒网址列表 
     * @return FakeURLInfos 仿冒网址列表
     */
    public FakeURLInfo [] getFakeURLInfos() {
        return this.FakeURLInfos;
    }

    /**
     * Set 仿冒网址列表
     * @param FakeURLInfos 仿冒网址列表
     */
    public void setFakeURLInfos(FakeURLInfo [] FakeURLInfos) {
        this.FakeURLInfos = FakeURLInfos;
    }

    /**
     * Get 总量 
     * @return TotalCount 总量
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 总量
     * @param TotalCount 总量
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 导出量 
     * @return ExportURL 导出量
     */
    public String getExportURL() {
        return this.ExportURL;
    }

    /**
     * Set 导出量
     * @param ExportURL 导出量
     */
    public void setExportURL(String ExportURL) {
        this.ExportURL = ExportURL;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeBPFakeURLsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeBPFakeURLsResponse(DescribeBPFakeURLsResponse source) {
        if (source.FakeURLInfos != null) {
            this.FakeURLInfos = new FakeURLInfo[source.FakeURLInfos.length];
            for (int i = 0; i < source.FakeURLInfos.length; i++) {
                this.FakeURLInfos[i] = new FakeURLInfo(source.FakeURLInfos[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.ExportURL != null) {
            this.ExportURL = new String(source.ExportURL);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "FakeURLInfos.", this.FakeURLInfos);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "ExportURL", this.ExportURL);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
